==========================
SciPy 1.6.1 Release Notes
==========================

.. contents::

SciPy 1.6.1 is a bug-fix release with no new features
compared to 1.6.0.

Please note that for SciPy wheels to correctly install with Pip on
macOS 11, Pip >= 20.3.3 is needed.


Authors
=======

* Peter Bell
* Evgeni Burovski
* CJ Carey
* Ralf Gommers
* Peter Mahler Larsen
* Cheng H. Lee +
* Cong Ma
* Nicholas McKibben
* Nikola Forró
* Tyler Reddy
* Warren Weckesser

A total of 11 people contributed to this release.
People with a "+" by their names contributed a patch for the first time.
This list of names is automatically generated, and may not be fully complete.

Issues closed for 1.6.1
-----------------------

* `#13072 <https://github.com/scipy/scipy/issues/13072>`__: BLD: Quadpack undefined references
* `#13241 <https://github.com/scipy/scipy/issues/13241>`__: Not enough values to unpack when passing tuple to \`blocksize\`...
* `#13329 <https://github.com/scipy/scipy/issues/13329>`__: Large sparse matrices of big integers lose information
* `#13342 <https://github.com/scipy/scipy/issues/13342>`__: fftn crashes if shape arguments are supplied as ndarrays
* `#13356 <https://github.com/scipy/scipy/issues/13356>`__: LSQBivariateSpline segmentation fault when quitting the Python...
* `#13358 <https://github.com/scipy/scipy/issues/13358>`__: scipy.spatial.transform.Rotation object can not be deepcopied...
* `#13408 <https://github.com/scipy/scipy/issues/13408>`__: Type of \`has_sorted_indices\` property
* `#13412 <https://github.com/scipy/scipy/issues/13412>`__: Sorting spherical Voronoi vertices leads to crash in area calculation
* `#13421 <https://github.com/scipy/scipy/issues/13421>`__: linear_sum_assignment - support for matrices with more than 2^31...
* `#13428 <https://github.com/scipy/scipy/issues/13428>`__: \`stats.exponnorm.cdf\` returns \`nan\` for small values of \`K\`...
* `#13465 <https://github.com/scipy/scipy/issues/13465>`__: KDTree.count_neighbors : 0xC0000005 error for tuple of different...
* `#13468 <https://github.com/scipy/scipy/issues/13468>`__: directed_hausdorff issue with shuffle
* `#13472 <https://github.com/scipy/scipy/issues/13472>`__: Failures on FutureWarnings with numpy 1.20.0 for lfilter, sosfilt...
* `#13565 <https://github.com/scipy/scipy/issues/13565>`__: BUG: 32-bit wheels repo test failure in optimize

Pull requests for 1.6.1
-----------------------

* `#13318 <https://github.com/scipy/scipy/pull/13318>`__: REL: prepare for SciPy 1.6.1
* `#13344 <https://github.com/scipy/scipy/pull/13344>`__: BUG: fftpack doesn't work with ndarray shape argument
* `#13345 <https://github.com/scipy/scipy/pull/13345>`__: MAINT: Replace scipy.take with numpy.take in FFT function docstrings.
* `#13354 <https://github.com/scipy/scipy/pull/13354>`__: BUG: optimize: rename private functions to include leading underscore
* `#13387 <https://github.com/scipy/scipy/pull/13387>`__: BUG: Support big-endian platforms and big-endian WAVs
* `#13394 <https://github.com/scipy/scipy/pull/13394>`__: BUG: Fix Python crash by allocating larger array in LSQBivariateSpline
* `#13400 <https://github.com/scipy/scipy/pull/13400>`__: BUG: sparse: Better validation for BSR ctor
* `#13403 <https://github.com/scipy/scipy/pull/13403>`__: BUG: sparse: Propagate dtype through CSR/CSC constructors
* `#13414 <https://github.com/scipy/scipy/pull/13414>`__: BUG: maintain dtype of SphericalVoronoi regions
* `#13422 <https://github.com/scipy/scipy/pull/13422>`__: FIX: optimize: use npy_intp to store array dims for lsap
* `#13425 <https://github.com/scipy/scipy/pull/13425>`__: BUG: spatial: make Rotation picklable
* `#13426 <https://github.com/scipy/scipy/pull/13426>`__: BUG: \`has_sorted_indices\` and \`has_canonical_format\` should...
* `#13430 <https://github.com/scipy/scipy/pull/13430>`__: BUG: stats: Fix exponnorm.cdf and exponnorm.sf for small K
* `#13470 <https://github.com/scipy/scipy/pull/13470>`__: MAINT: silence warning generated by \`spatial.directed_hausdorff\`
* `#13473 <https://github.com/scipy/scipy/pull/13473>`__: TST: fix failures due to new FutureWarnings in NumPy 1.21.dev0
* `#13479 <https://github.com/scipy/scipy/pull/13479>`__: MAINT: update directed_hausdorff Cython code
* `#13485 <https://github.com/scipy/scipy/pull/13485>`__: BUG: KDTree weighted count_neighbors doesn't work between two...
* `#13503 <https://github.com/scipy/scipy/pull/13503>`__: TST: fix \`test_fortranfile_read_mixed_record\` on big-endian...
* `#13518 <https://github.com/scipy/scipy/pull/13518>`__: DOC: document that pip >= 20.3.3 is needed for macOS 11
* `#13520 <https://github.com/scipy/scipy/pull/13520>`__: BLD: update reqs based on oldest-supported-numpy in pyproject.toml
* `#13567 <https://github.com/scipy/scipy/pull/13567>`__: TST, BUG: adjust tol on test_equivalence
